@@ -2,7 +2,19 @@ from __future__ import annotations
 
 from functools import partial
 from inspect import iscoroutinefunction
-from typing import Any, Awaitable, Callable, Generic, Iterable, Literal, Type, TypeVar, Union, cast, overload
+from typing import (
+    Any,
+    Awaitable,
+    Callable,
+    Generic,
+    Iterable,
+    Literal,
+    Type,
+    TypeVar,
+    Union,
+    cast,
+    overload,
+)
 
 from anyio import BrokenResourceError, create_memory_object_stream
 from anyio.streams.memory import MemoryObjectReceiveStream, MemoryObjectSendStream
@@ -15,7 +27,9 @@ from ._snapshot import Snapshot
 from ._transaction import NewTransaction, ReadTransaction, Transaction
 
 T = TypeVar("T", bound=BaseType)
-TransactionOrSubdocsEvent = TypeVar("TransactionOrSubdocsEvent", bound=TransactionEvent | SubdocsEvent)
+TransactionOrSubdocsEvent = TypeVar(
+    "TransactionOrSubdocsEvent", bound=TransactionEvent | SubdocsEvent
+)
 
 
 class Doc(BaseDoc, Generic[T]):
@@ -47,7 +61,11 @@ class Doc(BaseDoc, Generic[T]):
             allow_multithreading: Whether to allow the document to be used in different threads.
         """
         super().__init__(
-            client_id=client_id, skip_gc=skip_gc, doc=doc, Model=Model, allow_multithreading=allow_multithreading
+            client_id=client_id,
+            skip_gc=skip_gc,
+            doc=doc,
+            Model=Model,
+            allow_multithreading=allow_multithreading,
         )
         for k, v in init.items():
             self[k] = v
@@ -292,7 +310,8 @@ class Doc(BaseDoc, Generic[T]):
 
     def observe(
         self,
-        callback: Callable[[TransactionEvent], None] | Callable[[TransactionEvent], Awaitable[None]],
+        callback: Callable[[TransactionEvent], None]
+        | Callable[[TransactionEvent], Awaitable[None]],
     ) -> Subscription:
         """
         Subscribes a callback to be called with the document change event.
@@ -405,7 +424,9 @@ class Doc(BaseDoc, Generic[T]):
         observe = self.observe_subdocs if subdocs else self.observe
         if not self._send_streams[subdocs]:
             if async_transactions:
-                self._event_subscription[subdocs] = observe(partial(self._async_send_event, subdocs))
+                self._event_subscription[subdocs] = observe(
+                    partial(self._async_send_event, subdocs)
+                )
             else:
                 self._event_subscription[subdocs] = observe(partial(self._send_event, subdocs))
         send_stream, receive_stream = create_memory_object_stream[
